@@ -7,5 +7,11 @@ def main(args, parser, extra):
 
     from shpc.main import get_client
 
-    cli = get_client(quiet=args.quiet, settings_file=args.settings_file)
+    cli = get_client(
+        quiet=args.quiet,
+        settings_file=args.settings_file,
+        module=args.module,
+        container_tech=args.container_tech,
+    )
+
     cli.list(args.pattern, args.names_only)
