@@ -6,6 +6,7 @@ from shpc.main.client import Client as BaseClient
 from shpc.logger import logger
 from datetime import datetime
 import shpc.utils as utils
+import shpc.defaults as defaults
 from jinja2 import Template
 
 from glob import glob
@@ -36,6 +37,20 @@ class Client(BaseClient):
             template = Template(temp.read())
         return template
 
+    def _cleanup(self, module_dir):
+        """Given a module directory, delete up to lmod base"""
+        # Exit early if the module directory for some reason was removed
+        if not os.path.exists(module_dir):
+            return
+        shutil.rmtree(module_dir)
+
+        # If directories above it are empty, remove
+        while module_dir != self.settings.lmod_base:
+            module_dir = os.path.dirname(module_dir)
+            if not os.path.exists(module_dir) or os.listdir(module_dir):
+                break
+            shutil.rmtree(module_dir)
+
     def uninstall(self, name, force=False):
         """
         Given a unique resource identifier, uninstall a module
@@ -46,14 +61,7 @@ class Client(BaseClient):
         if os.path.exists(module_dir) and not force:
             msg = "%s, and all content below it? " % name
             if utils.confirm_uninstall(msg, force):
-                shutil.rmtree(module_dir)
-
-                # If directories above it are empty, remove
-                while module_dir != self.settings.lmod_base:
-                    module_dir = os.path.dirname(module_dir)
-                    if os.listdir(module_dir):
-                        break
-                    shutil.rmtree(module_dir)
+                self._cleanup(module_dir)
 
         elif os.path.exists(module_dir) and force:
             shutil.rmtree(module_dir)
@@ -143,6 +151,35 @@ class Client(BaseClient):
             self.settings.lmod_base, "module.lua", pattern, names_only, out
         )
 
+    def docgen(self, module_name, out=None):
+        """
+        Render documentation for a module.
+        """
+        out = out or sys.stdout
+        config = self._load_container(module_name)
+        aliases = config.get_aliases()
+        template = self._load_template("docs.md")
+        github_url = "%s/blob/main/registry/%s/container.yaml" % (
+            defaults.github_url,
+            module_name,
+        )
+
+        result = template.render(
+            singularity_module=self.settings.singularity_module,
+            singularity_shell=self.settings.singularity_shell,
+            bindpaths=self.settings.bindpaths,
+            description=config.description,
+            aliases=aliases,
+            versions=config.tags.keys(),
+            github_url=github_url,
+            url=config.url,
+            prefix=self.settings.lmod_exc_prefix,
+            creation_date=datetime.now(),
+            name=module_name,
+            flatname=module_name.replace("/", "-"),
+        )
+        out.write(result)
+
     def inspect(self, module_name):
         """
         Return complete metadata for the user from a container.
@@ -159,6 +196,10 @@ class Client(BaseClient):
         out = out or sys.stdout
         modules = self._get_module_lookup(base, filename, pattern)
 
+        # If we don't have modules, exit early
+        if not modules:
+            logger.exit("You don't have any install modules. Try shpc show.", 0)
+
         # The user can request to list only names, which is useful to find modules
         for module_name, versions in modules.items():
             if names_only:
@@ -296,12 +337,13 @@ class Client(BaseClient):
         elif pull_type == "gh":
             container_uri = "gh://%s/%s:%s" % (config.gh, tag.digest, tag.name)
 
-        # Pull new containers (this doesn't clean up old ones, which we might want to do)
+        # Pull new containers
         if not os.path.exists(container_path):
             self._container.pull(container_uri, container_path)
 
         # Exit early if there is an issue
         if not os.path.exists(container_path):
+            self._cleanup(os.path.dirname(container_path))
             logger.exit("There was an issue pulling %s" % container_path)
 
         # prepare aliases
